@@ -1,4 +1,6 @@
-# $Id: DAV.pm 158 2009-02-24 22:30:30Z cosimo $
+#
+# Perl WebDAV client library
+#
 
 package HTTP::DAV;
 
@@ -15,16 +17,11 @@ use FileHandle;
 use File::Glob;
 
 #use Carp (cluck);
-
 use Cwd qw(getcwd);  # Can't import all of it, cwd clashes with our namespace.
 
 # Globals
-$VERSION = '0.37';
-
-#sprintf("%d.%02d", q$Revision: 0.31 $ =~ /(\d+)\.(\d+)/);
-$VERSION_DATE = '2009/03/24';
-
-#sprintf("%s", q$Date: 2002/04/13 12:21:07 $ =~ m# (.*) $# );
+$VERSION = '0.39';
+$VERSION_DATE = '2009/12/12';
 
 $DEBUG = 0;          # Set this up to 3
 
@@ -378,7 +375,8 @@ sub _get {
         }
 
         # Try and make the directory locally
-        print "MKDIR $local_name (before escape)\n";
+        print "MKDIR $local_name (before escape)\n" if $DEBUG > 2;
+
         $local_name = URI::Escape::uri_unescape($local_name);
         if ( !mkdir $local_name ) {
             return $self->err( 'ERR_GENERIC',
@@ -430,21 +428,31 @@ sub _get {
 
             my $fh;
             my $put_to_scalar = 0;
+
             if ( $name_ref =~ /GLOB/ ) {
                 $fh = $local_name;
             }
+
             elsif ( $name_ref =~ /SCALAR/ ) {
                 $put_to_scalar = 1;
                 $$local_name   = "";
             }
+
             else {
                 $fh         = FileHandle->new;
                 $local_name = URI::Escape::uri_unescape($local_name);
-                if ( !$fh->open(">$local_name") ) {
-                    return $self->err( 'ERR_GENERIC',
-                        "open \">$local_name\" failed: $!", $url );
+                if (! $fh->open(">$local_name") ) {
+                    return $self->err(
+                        'ERR_GENERIC',
+                        "open \">$local_name\" failed: $!",
+                        $url
+                    );
                 }
+
+                # RT #29788, avoid file corruptions on Win32
+                binmode $fh;
             }
+
             $self->{_fh} = $fh;
 
             $response = $resource->get(
@@ -966,7 +974,7 @@ sub _put {
             }
         }
 
-        # PUT A FILE
+    # PUT A FILE
     }
     else {
         my $content = "";
@@ -1888,7 +1896,7 @@ This value will always be the same as the value returned from an HTTP::DAV::meth
 You may want to use the is_success method if you didn't capture the return value immediately. But in most circumstances you're better off just evaluating as follows:
   if($d->lock($url)) { ... }
 
-=item B<get_lastresponse>
+=item B<get_last_response>
 
 Takes no arguments and returns the last seen C<HTTP::DAV::Response> object. 
 
@@ -1896,13 +1904,13 @@ You may want to use this if you have just called a propfind and need the individ
 
 If you find that you're using get_last_response() method a lot, you may be better off using the more advanced C<HTTP::DAV> interface and interacting with the HTTP::DAV::* interfaces directly as discussed in the intro. For instance, if you find that you're always wanting a detailed understanding of the server's response headers or messages, then you're probably better off using the C<HTTP::DAV::Resource> methods and interpreting the C<HTTP::DAV::Response> directly.
 
-To perform detailed analysis of the server's response (if for instance you got back a multistatus response) you can call get_lastresponse which will return to you the most recent response object (always the result of the last operation, PUT, PROPFIND, etc). With the returned HTTP::DAV::Response object you can handle multi-status responses.
+To perform detailed analysis of the server's response (if for instance you got back a multistatus response) you can call C<get_last_response()> which will return to you the most recent response object (always the result of the last operation, PUT, PROPFIND, etc). With the returned HTTP::DAV::Response object you can handle multi-status responses.
 
 For example:
 
    # Print all of the messages in a multistatus response
    if (! $d->unlock($url) ) {
-      $response = $d->get_lastresponse();
+      $response = $d->get_last_response();
       if ($response->is_multistatus() ) {
         foreach $num ( 0 .. $response->response_count() ) {
            ($err_code,$mesg,$url,$desc) =
@@ -1942,6 +1950,8 @@ resource is valid.
 
 =head1 INSTALLATION, TODO, MAILING LISTS and REVISION HISTORY
 
+[OUTDATED]
+
 Please see the primary HTTP::DAV webpage at
 (http://www.webdav.org/perldav/http-dav/)
 or the README file in this library.
@@ -1991,8 +2001,8 @@ This module is Copyright (C) 2001-2008 by
 
 All rights reserved.
 
-Current co-maintainer of the module is Opera Software ASA,
-L<opera@cpan.org>.
+Current co-maintainer of the module is Cosimo Streppone
+for Opera Software ASA, L<opera@cpan.org>.
 
 You may distribute this module under the terms of either the
 GNU General Public License or the Artistic License,
